;*******************(ASM) COPYRIGHT 2023 Masses-Chip ****************************
;* Project Name		  : M8P625_TC1.Prj
;* File Name		  : M8P625_TC1.ASM
;* Author			  : MASSES CHIP
;* Version           		 : V1.05
;* Date              		 : 2024/03/05
;* Web				  : www.masses-chip.com
;* FAE				  : Luo
;					  : QQ：411680975
;//******************************************************************************
;
;Option:16M/16T,WDT-Enable-288ms,RST-IO,BOR 2.4V 
;说明：本范例以TC1为定时器，大概1ms翻转一次IOA0口
;16位计数器无自动重载功能，中断需要重新加载计数器初值，定时时间会有些许影响
;//******************************************************************************
;//===============================================================================
;//***********************************头文件**************************************
;//用户不可更改
;//===============================================================================
#INCLUDE	 	 ZC.INC

;//===============================================================================
;//******************************定义全局变量*************************************
;//用户可以自行看需求定义变量
;//===============================================================================
userdata	udata		H'00'
R_Flag		res			1
#define	b_TC1_Flag		R_Flag,0

;//===============================================================================
;//**********************************CODE*****************************************
;//===============================================================================
		ORG			 0000H
		GOTO		 MainProgram
		ORG			 0008H
		GOTO		 Interrupt

;//===============================================================================
;//*********************************主函数****************************************
;//主循环每1ms翻转一次IOA0
;//===============================================================================
MainProgram:
		CALL         System_Init           ;//系统初始化
        CALL		 Clr_RAM_00H_7FH       ;//清零RAM		
		CALL         TC1_Init              ;//TC0初始化	 
;//----------------------主函数循环--------------------------------------------		
MainLoop:
		CLRWDT                             ;//清除看门狗
		JBTS1		b_TC1_Flag
		GOTO		MainLoop
		BCLR		b_TC1_Flag
		JBTS1		IOA,0
		GOTO		Set_IO_H
		BCLR		IOA,0
		GOTO		MainLoop
Set_IO_H:
		BSET		IOA,0
		GOTO		MainLoop			

;//===============================================================================
;//******************************中断处理程序*************************************
;//定时中断，标志位置高
;//===============================================================================
Interrupt:
		PUSH                               ;//压栈,保存A,STATUS
;//中断处理程序
		JBTS1		INTF0,1
		GOTO		Interrupt_END
		BCLR		INTF0,1
		MOVIA		0x18
		MOVAR		TC1CL
		MOVIA		0xFC
		MOVAR		TC1CH					;//16位重新装载		
		BSET		b_TC1_Flag
Interrupt_END:		          
		POP                                ;//出栈,恢复A,STATUS
		RETIE			      		

;//===============================================================================
;//*********************************TC1初始化*************************************
;//TC1设置：8位模式、高频16M 16分频，定时为1ms
;//t =计数/（时钟/分频）     1ms = （999+1）/（16/16）
;//开启TC1溢出中断和总中断
;//===============================================================================	
TC1_Init:
;//1、TC1设置
		MOVIA		0x4C
		MOVAR		T1CR
		MOVIA		0x18
		MOVAR		TC1CL
		MOVIA		0xFC
		MOVAR		TC1CH
		BSET		T1CR,7
;//2、中断设置
		BCLR		INTF0,1
		BSET		INTCR0,1
		BSET		OPTION,7
		RETURN

;//===============================================================================
;//**********************************系统初始化***********************************
;//系统时钟初始化：快钟、慢钟都正常工作，不进休眠
;//IO初始化:设置IO状态为输出低，且关闭上下拉
;//中断总开关：关闭总开关
;//===============================================================================		
SYSTEM_INIT:
;//-----------------------------------------------------------------------           
;//SystemInit Clock		      
		MOVIA      	0x00
        MOVAR      	OSCM
;//----------------------------------------------------------------------      
;//Init IO 
		;//IOA
		MOVIA      	0x00    	;//0:上拉关闭 1:上拉使能
        MOVAR      	PUA
        MOVIA      	0xFF    	;//0:输入 1:输出
        MOVAR      	OEA
        MOVIA      	0x00    	;//IO口数据
        MOVAR      	IOA     
        ;//IOB
		MOVIA      	0x00    
        MOVAR      	PUB
        MOVIA      	0xFF	  
        MOVAR      	OEB
        MOVIA      	0x00   
        MOVAR      	IOB
		;//IOC
		MOVIA      	0x00  
        MOVAR      	PUC
		MOVIA      	0xFF    
        MOVAR      	OEC
		MOVIA      	0x00    
        MOVAR      	IOC 
;//----------------------------------------------------------------------      
;//中断设置  				
		BCLR     	OPTION,GIE  ;//1:总中断使能,0:屏蔽所有中断	
		RETURN

;//===============================================================================
;//****************************RAM清零(00H~7FH)***********************************
;//RAM清零：RAM区0000H~007FH全部清零
;//===============================================================================       	
Clr_RAM_00H_7FH:
		CLRR		FSR0   		;//从00地址开始写入
Clr_RAM_00H_7FH_LOOP:	
		MOVIA       0x00
		MOVAR		INDF0
		INCR		FSR0,1
		JBTS1		FSR0,7
		GOTO		Clr_RAM_00H_7FH_LOOP
		RETURN
		END

;//*************************END OF FILE******************************************